aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorArturo Espinosa <unammx@src.gnome.org>2000-01-26 08:04:16 +0800
committerArturo Espinosa <unammx@src.gnome.org>2000-01-26 08:04:16 +0800
commit9f31ce86ff0ac0c7997e977647339ffb2db0fd63 (patch)
tree36a8cf18685d0aae7a37169c72f57b53e44f94f0
parent490b4ff6ec666a14e4f4bf0431aa7aa15b452366 (diff)
downloadgsoc2013-evolution-9f31ce86ff0ac0c7997e977647339ffb2db0fd63.tar
gsoc2013-evolution-9f31ce86ff0ac0c7997e977647339ffb2db0fd63.tar.gz
gsoc2013-evolution-9f31ce86ff0ac0c7997e977647339ffb2db0fd63.tar.bz2
gsoc2013-evolution-9f31ce86ff0ac0c7997e977647339ffb2db0fd63.tar.lz
gsoc2013-evolution-9f31ce86ff0ac0c7997e977647339ffb2db0fd63.tar.xz
gsoc2013-evolution-9f31ce86ff0ac0c7997e977647339ffb2db0fd63.tar.zst
gsoc2013-evolution-9f31ce86ff0ac0c7997e977647339ffb2db0fd63.zip
Make Evolution compile with the latest Bonobo changes.
Make Evolution compile with the latest Bonobo changes. Miguel. svn path=/trunk/; revision=1636
-rw-r--r--Makefile.am1
-rw-r--r--README7
-rw-r--r--calendar/GnomeCal.idl2
-rw-r--r--calendar/Makefile.am3
-rw-r--r--calendar/cal-client.c2
-rw-r--r--calendar/cal-client/cal-client.c2
-rw-r--r--calendar/cal-client/cal-listener.c28
-rw-r--r--calendar/cal-client/cal-listener.h8
-rw-r--r--calendar/cal-factory.c26
-rw-r--r--calendar/cal-factory.h8
-rw-r--r--calendar/cal-listener.c28
-rw-r--r--calendar/cal-listener.h8
-rw-r--r--calendar/cal.c22
-rw-r--r--calendar/cal.h8
-rw-r--r--calendar/corba-cal-factory.c18
-rw-r--r--calendar/evolution-calendar.idl8
-rw-r--r--calendar/gui/GnomeCal.idl2
-rw-r--r--calendar/gui/Makefile.am3
-rw-r--r--calendar/gui/corba-cal-factory.c18
-rw-r--r--calendar/gui/prop.c2
-rw-r--r--calendar/idl/evolution-calendar.idl8
-rw-r--r--calendar/pcs/cal-factory.c26
-rw-r--r--calendar/pcs/cal-factory.h8
-rw-r--r--calendar/pcs/cal.c22
-rw-r--r--calendar/pcs/cal.h8
-rw-r--r--calendar/pcs/tlacuache.c4
-rw-r--r--calendar/prop.c2
-rw-r--r--calendar/tlacuache.c4
-rw-r--r--configure.in5
-rw-r--r--mail/Mail.idl6
-rw-r--r--mail/Makefile.am4
-rw-r--r--mail/folder-browser-factory.c15
-rw-r--r--mail/folder-browser.c6
-rw-r--r--mail/folder-browser.h2
-rw-r--r--mail/mail-component.c2
-rw-r--r--mail/main.c4
-rw-r--r--mail/message-list.c22
-rw-r--r--mail/message-list.h10
-rw-r--r--shell/Evolution.idl34
-rw-r--r--shell/Makefile.am2
-rw-r--r--shell/e-shell-view-menu.c14
-rw-r--r--shell/e-shell-view.h6
-rw-r--r--shell/e-shell.c56
-rw-r--r--shell/e-shell.h6
-rw-r--r--shell/main.c2
45 files changed, 243 insertions, 239 deletions
diff --git a/Makefile.am b/Makefile.am
index 9634d0b81c..dbf1f33179 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -10,6 +10,7 @@ EXTRA_DIST = \
NEWS
SUBDIRS = \
+ intl \
po \
macros \
data \
diff --git a/README b/README
index 9b4f6c7ca8..b82df79654 100644
--- a/README
+++ b/README
@@ -1,3 +1,6 @@
-This is the future gnome mailer.
-See camel/README for details about the mail library. \ No newline at end of file
+Evolution is the integrated mail, calendar and address book
+distributed suite from Helix Code, Inc.
+
+http://www.helixcode.com for more information.
+
diff --git a/calendar/GnomeCal.idl b/calendar/GnomeCal.idl
index a58358f3f1..1e426fae36 100644
--- a/calendar/GnomeCal.idl
+++ b/calendar/GnomeCal.idl
@@ -1,3 +1,5 @@
+#include <Bonobo.idl>
+
module GNOME {
module Calendar {
diff --git a/calendar/Makefile.am b/calendar/Makefile.am
index 89f6becfa1..fd7767ebcc 100644
--- a/calendar/Makefile.am
+++ b/calendar/Makefile.am
@@ -138,8 +138,7 @@ tlacuache_SOURCES = \
tlacuache.c
LINK_FLAGS = \
- $(GNOME_LIBDIR) \
- $(GNOMEGNORBA_LIBS) \
+ $(BONOBO_VFS_GNOME_LIBS) \
$(INTLLIBS) \
../libversit/libversit.la
diff --git a/calendar/cal-client.c b/calendar/cal-client.c
index 0f6b31c06a..91d83d2cad 100644
--- a/calendar/cal-client.c
+++ b/calendar/cal-client.c
@@ -270,7 +270,7 @@ cal_client_load_calendar (CalClient *client, const char *str_uri)
return FALSE;
}
- corba_listener = (GNOME_Calendar_Listener) gnome_object_corba_objref (priv->listener);
+ corba_listener = (GNOME_Calendar_Listener) bonobo_object_corba_objref (priv->listener);
CORBA_exception_init (&ev);
diff --git a/calendar/cal-client/cal-client.c b/calendar/cal-client/cal-client.c
index 0f6b31c06a..91d83d2cad 100644
--- a/calendar/cal-client/cal-client.c
+++ b/calendar/cal-client/cal-client.c
@@ -270,7 +270,7 @@ cal_client_load_calendar (CalClient *client, const char *str_uri)
return FALSE;
}
- corba_listener = (GNOME_Calendar_Listener) gnome_object_corba_objref (priv->listener);
+ corba_listener = (GNOME_Calendar_Listener) bonobo_object_corba_objref (priv->listener);
CORBA_exception_init (&ev);
diff --git a/calendar/cal-client/cal-listener.h b/calendar/cal-client/cal-listener.h
index c8d26dab80..22853212ee 100644
--- a/calendar/cal-client/cal-listener.h
+++ b/calendar/cal-client/cal-listener.h
@@ -23,7 +23,7 @@
#define CAL_LISTENER_H
#include <libgnome/gnome-defs.h>
-#include <bonobo/gnome-object.h>
+#include <bonobo/bonobo-object.h>
#include "gnome-calendar.h"
BEGIN_GNOME_DECLS
@@ -47,14 +47,14 @@ typedef enum {
} CalListenerLoadStatus;
struct _CalListener {
- GnomeObject object;
+ BonoboObject object;
/* Private data */
gpointer priv;
};
struct _CalListenerClass {
- GnomeObjectClass parent_class;
+ BonoboObjectClass parent_class;
void (* cal_loaded) (CalListener *listener,
CalListenerLoadStatus status,
@@ -67,7 +67,7 @@ struct _CalListenerClass {
GtkType cal_listener_get_type (void);
CalListener *cal_listener_construct (CalListener *listener, GNOME_Calendar_Listener corba_listener);
-GNOME_Calendar_Listener cal_listener_corba_object_create (GnomeObject *object);
+GNOME_Calendar_Listener cal_listener_corba_object_create (BonoboObject *object);
CalListener *cal_listener_new (void);
diff --git a/calendar/cal-factory.h b/calendar/cal-factory.h
index 0c227148c2..18f59d48b8 100644
--- a/calendar/cal-factory.h
+++ b/calendar/cal-factory.h
@@ -23,7 +23,7 @@
#define CAL_FACTORY_H
#include <libgnome/gnome-defs.h>
-#include <bonobo/gnome-object.h>
+#include <bonobo/bonobo-object.h>
#include "gnome-calendar.h"
BEGIN_GNOME_DECLS
@@ -41,20 +41,20 @@ typedef struct _CalFactory CalFactory;
typedef struct _CalFactoryClass CalFactoryClass;
struct _CalFactory {
- GnomeObject object;
+ BonoboObject object;
/* Private data */
gpointer priv;
};
struct _CalFactoryClass {
- GnomeObjectClass parent_class;
+ BonoboObjectClass parent_class;
};
GtkType cal_factory_get_type (void);
CalFactory *cal_factory_construct (CalFactory *factory, GNOME_Calendar_CalFactory corba_factory);
-GNOME_Calendar_CalFactory cal_factory_corba_object_create (GnomeObject *object);
+GNOME_Calendar_CalFactory cal_factory_corba_object_create (BonoboObject *object);
CalFactory *cal_factory_new (void);
diff --git a/calendar/cal-listener.h b/calendar/cal-listener.h
index c8d26dab80..22853212ee 100644
--- a/calendar/cal-listener.h
+++ b/calendar/cal-listener.h
@@ -23,7 +23,7 @@
#define CAL_LISTENER_H
#include <libgnome/gnome-defs.h>
-#include <bonobo/gnome-object.h>
+#include <bonobo/bonobo-object.h>
#include "gnome-calendar.h"
BEGIN_GNOME_DECLS
@@ -47,14 +47,14 @@ typedef enum {
} CalListenerLoadStatus;
struct _CalListener {
- GnomeObject object;
+ BonoboObject object;
/* Private data */
gpointer priv;
};
struct _CalListenerClass {
- GnomeObjectClass parent_class;
+ BonoboObjectClass parent_class;
void (* cal_loaded) (CalListener *listener,
CalListenerLoadStatus status,
@@ -67,7 +67,7 @@ struct _CalListenerClass {
GtkType cal_listener_get_type (void);
CalListener *cal_listener_construct (CalListener *listener, GNOME_Calendar_Listener corba_listener);
-GNOME_Calendar_Listener cal_listener_corba_object_create (GnomeObject *object);
+GNOME_Calendar_Listener cal_listener_corba_object_create (BonoboObject *object);
CalListener *cal_listener_new (void);
diff --git a/calendar/cal.h b/calendar/cal.h
index 80d349d44d..9ac7abc06d 100644
--- a/calendar/cal.h
+++ b/calendar/cal.h
@@ -23,7 +23,7 @@
#define CAL_H
#include <libgnome/gnome-defs.h>
-#include <bonobo/gnome-object.h>
+#include <bonobo/bonobo-object.h>
#include "gnome-calendar.h"
#include "cal-common.h"
@@ -38,14 +38,14 @@ BEGIN_GNOME_DECLS
#define IS_CAL_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), CAL_TYPE))
struct _Cal {
- GnomeObject object;
+ BonoboObject object;
/* Private data */
gpointer priv;
};
struct _CalClass {
- GnomeObjectClass parent_class;
+ BonoboObjectClass parent_class;
};
GtkType cal_get_type (void);
@@ -54,7 +54,7 @@ Cal *cal_construct (Cal *cal,
GNOME_Calendar_Cal corba_cal,
CalBackend *backend,
GNOME_Calendar_Listener listener);
-GNOME_Calendar_Cal cal_corba_object_create (GnomeObject *object);
+GNOME_Calendar_Cal cal_corba_object_create (BonoboObject *object);
Cal *cal_new (CalBackend *backend, GNOME_Calendar_Listener listener);
diff --git a/calendar/corba-cal-factory.c b/calendar/corba-cal-factory.c
index c10929376b..a86af3c238 100644
--- a/calendar/corba-cal-factory.c
+++ b/calendar/corba-cal-factory.c
@@ -14,8 +14,8 @@
#include "alarm.h"
#include "timeutil.h"
#include "../libversit/vcc.h"
-#include <libgnorba/gnome-factory.h>
#include <libgnorba/gnorba.h>
+#include <bonobo.h>
#include "GnomeCal.h"
#include "corba-cal-factory.h"
#include "corba-cal.h"
@@ -24,14 +24,14 @@ CORBA_ORB orb;
PortableServer_POA poa;
PortableServer_POAManager poa_manager;
-static POA_GNOME_GenericFactory__epv calendar_epv;
-static POA_GNOME_GenericFactory__vepv calendar_vepv;
+static POA_Bonobo_GenericFactory__epv calendar_epv;
+static POA_Bonobo_GenericFactory__vepv calendar_vepv;
/*
* Servant and Object Factory
*/
-static POA_GNOME_GenericFactory calendar_servant;
-static GNOME_GenericFactory calendar_factory;
+static POA_Bonobo_GenericFactory calendar_servant;
+static Bonobo_GenericFactory calendar_factory;
static CORBA_boolean
calendar_supports (PortableServer_Servant servant,
@@ -61,7 +61,7 @@ calendar_create_object (PortableServer_Servant servant,
if (strcmp (goad_id, "IDL:GNOME:Calendar:Repository:1.0") != 0){
CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
- ex_GNOME_GenericFactory_CannotActivate,
+ ex_Bonobo_GenericFactory_CannotActivate,
NULL);
return CORBA_OBJECT_NIL;
}
@@ -72,7 +72,7 @@ calendar_create_object (PortableServer_Servant servant,
if (stat (name, &s) != 0){
CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
- ex_GNOME_GenericFactory_CannotActivate,
+ ex_Bonobo_GenericFactory_CannotActivate,
NULL);
return CORBA_OBJECT_NIL;
}
@@ -99,12 +99,12 @@ init_corba_server (void)
PortableServer_POAManager_activate (poa_manager, &ev);
/* First create the locator for the repositories as a factory object */
- calendar_vepv.GNOME_GenericFactory_epv = &calendar_epv;
+ calendar_vepv.Bonobo_GenericFactory_epv = &calendar_epv;
calendar_epv.supports = calendar_supports;
calendar_epv.create_object = calendar_create_object;
calendar_servant.vepv = &calendar_vepv;
- POA_GNOME_GenericFactory__init ((PortableServer_Servant) &calendar_servant, &ev);
+ POA_Bonobo_GenericFactory__init ((PortableServer_Servant) &calendar_servant, &ev);
CORBA_free (PortableServer_POA_activate_object (
poa, (PortableServer_Servant)&calendar_servant, &ev));
diff --git a/calendar/evolution-calendar.idl b/calendar/evolution-calendar.idl
index 5c39956170..4fc6edd9b2 100644
--- a/calendar/evolution-calendar.idl
+++ b/calendar/evolution-calendar.idl
@@ -10,7 +10,7 @@
#ifndef _GNOME_CALENDAR_IDL_
#define _GNOME_CALENDAR_IDL_
-#include <gnome-unknown.idl>
+#include <Bonobo.idl>
module GNOME {
@@ -26,13 +26,13 @@ module Calendar {
interface Listener;
/* Calendar client interface */
- interface Cal : Unknown {
+ interface Cal : Bonobo::Unknown {
/* A calendar is identified by its URI */
readonly attribute string uri;
};
/* Listener for changes in a calendar */
- interface Listener : Unknown {
+ interface Listener : Bonobo::Unknown {
/* Return status when loading a calendar; we need better error reporting */
enum LoadStatus {
SUCESSS,
@@ -55,7 +55,7 @@ module Calendar {
};
/* A calendar factory, can load and create calendars */
- interface CalFactory : Unknown {
+ interface CalFactory : Bonobo::Unknown {
exception NilListener {};
/* Load a calendar from an URI */
diff --git a/calendar/gui/GnomeCal.idl b/calendar/gui/GnomeCal.idl
index a58358f3f1..1e426fae36 100644
--- a/calendar/gui/GnomeCal.idl
+++ b/calendar/gui/GnomeCal.idl
@@ -1,3 +1,5 @@
+#include <Bonobo.idl>
+
module GNOME {
module Calendar {
diff --git a/calendar/gui/Makefile.am b/calendar/gui/Makefile.am
index 89f6becfa1..fd7767ebcc 100644
--- a/calendar/gui/Makefile.am
+++ b/calendar/gui/Makefile.am
@@ -138,8 +138,7 @@ tlacuache_SOURCES = \
tlacuache.c
LINK_FLAGS = \
- $(GNOME_LIBDIR) \
- $(GNOMEGNORBA_LIBS) \
+ $(BONOBO_VFS_GNOME_LIBS) \
$(INTLLIBS) \
../libversit/libversit.la
diff --git a/calendar/gui/corba-cal-factory.c b/calendar/gui/corba-cal-factory.c
index c10929376b..a86af3c238 100644
--- a/calendar/gui/corba-cal-factory.c
+++ b/calendar/gui/corba-cal-factory.c
@@ -14,8 +14,8 @@
#include "alarm.h"
#include "timeutil.h"
#include "../libversit/vcc.h"
-#include <libgnorba/gnome-factory.h>
#include <libgnorba/gnorba.h>
+#include <bonobo.h>
#include "GnomeCal.h"
#include "corba-cal-factory.h"
#include "corba-cal.h"
@@ -24,14 +24,14 @@ CORBA_ORB orb;
PortableServer_POA poa;
PortableServer_POAManager poa_manager;
-static POA_GNOME_GenericFactory__epv calendar_epv;
-static POA_GNOME_GenericFactory__vepv calendar_vepv;
+static POA_Bonobo_GenericFactory__epv calendar_epv;
+static POA_Bonobo_GenericFactory__vepv calendar_vepv;
/*
* Servant and Object Factory
*/
-static POA_GNOME_GenericFactory calendar_servant;
-static GNOME_GenericFactory calendar_factory;
+static POA_Bonobo_GenericFactory calendar_servant;
+static Bonobo_GenericFactory calendar_factory;
static CORBA_boolean
calendar_supports (PortableServer_Servant servant,
@@ -61,7 +61,7 @@ calendar_create_object (PortableServer_Servant servant,
if (strcmp (goad_id, "IDL:GNOME:Calendar:Repository:1.0") != 0){
CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
- ex_GNOME_GenericFactory_CannotActivate,
+ ex_Bonobo_GenericFactory_CannotActivate,
NULL);
return CORBA_OBJECT_NIL;
}
@@ -72,7 +72,7 @@ calendar_create_object (PortableServer_Servant servant,
if (stat (name, &s) != 0){
CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
- ex_GNOME_GenericFactory_CannotActivate,
+ ex_Bonobo_GenericFactory_CannotActivate,
NULL);
return CORBA_OBJECT_NIL;
}
@@ -99,12 +99,12 @@ init_corba_server (void)
PortableServer_POAManager_activate (poa_manager, &ev);
/* First create the locator for the repositories as a factory object */
- calendar_vepv.GNOME_GenericFactory_epv = &calendar_epv;
+ calendar_vepv.Bonobo_GenericFactory_epv = &calendar_epv;
calendar_epv.supports = calendar_supports;
calendar_epv.create_object = calendar_create_object;
calendar_servant.vepv = &calendar_vepv;
- POA_GNOME_GenericFactory__init ((PortableServer_Servant) &calendar_servant, &ev);
+ POA_Bonobo_GenericFactory__init ((PortableServer_Servant) &calendar_servant, &ev);
CORBA_free (PortableServer_POA_activate_object (
poa, (PortableServer_Servant)&calendar_servant, &ev));
diff --git a/calendar/gui/prop.c b/calendar/gui/prop.c
index 6f2fec605b..8e91f4d730 100644
--- a/calendar/gui/prop.c
+++ b/calendar/gui/prop.c
@@ -776,7 +776,7 @@ create_alarm_page (void)
main_box = gtk_vbox_new (FALSE, GNOME_PAD);
gtk_container_set_border_width (GTK_CONTAINER (main_box), GNOME_PAD_SMALL);
gnome_property_box_append_page (GNOME_PROPERTY_BOX (prop_win),
- main_box, gtk_label_new (_("Alarms")));
+ main_box, gtk_label_new (_("Alarms")));
/* build miscellaneous box */
misc_frame = gtk_frame_new (_("Alarm Properties"));
diff --git a/calendar/idl/evolution-calendar.idl b/calendar/idl/evolution-calendar.idl
index 5c39956170..4fc6edd9b2 100644
--- a/calendar/idl/evolution-calendar.idl
+++ b/calendar/idl/evolution-calendar.idl
@@ -10,7 +10,7 @@
#ifndef _GNOME_CALENDAR_IDL_
#define _GNOME_CALENDAR_IDL_
-#include <gnome-unknown.idl>
+#include <Bonobo.idl>
module GNOME {
@@ -26,13 +26,13 @@ module Calendar {
interface Listener;
/* Calendar client interface */
- interface Cal : Unknown {
+ interface Cal : Bonobo::Unknown {
/* A calendar is identified by its URI */
readonly attribute string uri;
};
/* Listener for changes in a calendar */
- interface Listener : Unknown {
+ interface Listener : Bonobo::Unknown {
/* Return status when loading a calendar; we need better error reporting */
enum LoadStatus {
SUCESSS,
@@ -55,7 +55,7 @@ module Calendar {
};
/* A calendar factory, can load and create calendars */
- interface CalFactory : Unknown {
+ interface CalFactory : Bonobo::Unknown {
exception NilListener {};
/* Load a calendar from an URI */
diff --git a/calendar/pcs/cal-factory.h b/calendar/pcs/cal-factory.h
index 0c227148c2..18f59d48b8 100644
--- a/calendar/pcs/cal-factory.h
+++ b/calendar/pcs/cal-factory.h
@@ -23,7 +23,7 @@
#define CAL_FACTORY_H
#include <libgnome/gnome-defs.h>
-#include <bonobo/gnome-object.h>
+#include <bonobo/bonobo-object.h>
#include "gnome-calendar.h"
BEGIN_GNOME_DECLS
@@ -41,20 +41,20 @@ typedef struct _CalFactory CalFactory;
typedef struct _CalFactoryClass CalFactoryClass;
struct _CalFactory {
- GnomeObject object;
+ BonoboObject object;
/* Private data */
gpointer priv;
};
struct _CalFactoryClass {
- GnomeObjectClass parent_class;
+ BonoboObjectClass parent_class;
};
GtkType cal_factory_get_type (void);
CalFactory *cal_factory_construct (CalFactory *factory, GNOME_Calendar_CalFactory corba_factory);
-GNOME_Calendar_CalFactory cal_factory_corba_object_create (GnomeObject *object);
+GNOME_Calendar_CalFactory cal_factory_corba_object_create (BonoboObject *object);
CalFactory *cal_factory_new (void);
diff --git a/calendar/pcs/cal.h b/calendar/pcs/cal.h
index 80d349d44d..9ac7abc06d 100644
--- a/calendar/pcs/cal.h
+++ b/calendar/pcs/cal.h
@@ -23,7 +23,7 @@
#define CAL_H
#include <libgnome/gnome-defs.h>
-#include <bonobo/gnome-object.h>
+#include <bonobo/bonobo-object.h>
#include "gnome-calendar.h"
#include "cal-common.h"
@@ -38,14 +38,14 @@ BEGIN_GNOME_DECLS
#define IS_CAL_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), CAL_TYPE))
struct _Cal {
- GnomeObject object;
+ BonoboObject object;
/* Private data */
gpointer priv;
};
struct _CalClass {
- GnomeObjectClass parent_class;
+ BonoboObjectClass parent_class;
};
GtkType cal_get_type (void);
@@ -54,7 +54,7 @@ Cal *cal_construct (Cal *cal,
GNOME_Calendar_Cal corba_cal,
CalBackend *backend,
GNOME_Calendar_Listener listener);
-GNOME_Calendar_Cal cal_corba_object_create (GnomeObject *object);
+GNOME_Calendar_Cal cal_corba_object_create (BonoboObject *object);
Cal *cal_new (CalBackend *backend, GNOME_Calendar_Listener listener);
diff --git a/calendar/pcs/tlacuache.c b/calendar/pcs/tlacuache.c
index 0af24d1829..b11b5030d8 100644
--- a/calendar/pcs/tlacuache.c
+++ b/calendar/pcs/tlacuache.c
@@ -21,7 +21,7 @@
#include <config.h>
#include <libgnorba/gnorba.h>
-#include <bonobo/gnome-bonobo.h>
+#include <bonobo.h>
#include <libgnomevfs/gnome-vfs.h>
#include "cal-factory.h"
#include "calobj.h"
@@ -68,7 +68,7 @@ create_cal_factory (void)
return FALSE;
}
- object = gnome_object_corba_objref (GNOME_OBJECT (factory));
+ object = bonobo_object_corba_objref (BONOBO_OBJECT (factory));
CORBA_exception_init (&ev);
result = goad_server_register (CORBA_OBJECT_NIL,
diff --git a/calendar/prop.c b/calendar/prop.c
index 6f2fec605b..8e91f4d730 100644
--- a/calendar/prop.c
+++ b/calendar/prop.c
@@ -776,7 +776,7 @@ create_alarm_page (void)
main_box = gtk_vbox_new (FALSE, GNOME_PAD);
gtk_container_set_border_width (GTK_CONTAINER (main_box), GNOME_PAD_SMALL);
gnome_property_box_append_page (GNOME_PROPERTY_BOX (prop_win),
- main_box, gtk_label_new (_("Alarms")));
+ main_box, gtk_label_new (_("Alarms")));
/* build miscellaneous box */
misc_frame = gtk_frame_new (_("Alarm Properties"));
diff --git a/calendar/tlacuache.c b/calendar/tlacuache.c
index 0af24d1829..b11b5030d8 100644
--- a/calendar/tlacuache.c
+++ b/calendar/tlacuache.c
@@ -21,7 +21,7 @@
#include <config.h>
#include <libgnorba/gnorba.h>
-#include <bonobo/gnome-bonobo.h>
+#include <bonobo.h>
#include <libgnomevfs/gnome-vfs.h>
#include "cal-factory.h"
#include "calobj.h"
@@ -68,7 +68,7 @@ create_cal_factory (void)
return FALSE;
}
- object = gnome_object_corba_objref (GNOME_OBJECT (factory));
+ object = bonobo_object_corba_objref (BONOBO_OBJECT (factory));
CORBA_exception_init (&ev);
result = goad_server_register (CORBA_OBJECT_NIL,
diff --git a/configure.in b/configure.in
index 805df382d5..592c5bf9fd 100644
--- a/configure.in
+++ b/configure.in
@@ -69,12 +69,12 @@ dnl AC_SUBST(GNOMEGNORBA_LIBS)
dnl ******************************
dnl Check for Bonobo
dnl ******************************
-AC_MSG_CHECKING(for Bonobo > 0.4)
+AC_MSG_CHECKING(for Bonobo > 0.5)
if gnome-config --libs bonobo > /dev/null 2>&1; then
vers=`gnome-config --modversion bonobo`
case $vers
in
- bonobo-0.[[01234]]) bonobo_ok=false ;;
+ bonobo-0.[[012345]]) bonobo_ok=false ;;
*) bonobo_ok=true ;;
esac
else
@@ -166,6 +166,7 @@ macros/Makefile
intl/Makefile
po/Makefile.in
e-util/Makefile
+doc/Makefile
camel/Makefile
camel/providers/Makefile
camel/providers/MH/Makefile
diff --git a/mail/Mail.idl b/mail/Mail.idl
index 74c6ba74d4..1d12a39c5c 100644
--- a/mail/Mail.idl
+++ b/mail/Mail.idl
@@ -7,11 +7,11 @@
* (C) 2000 Helix Code, Inc.
*/
-#include <bonobo.idl>
+#include <Bonobo.idl>
module Evolution {
- interface MessageList : GNOME::Unknown {
+ interface MessageList : Bonobo::Unknown {
void select_message (in long message_number);
void open_message (in long message_number);
@@ -23,7 +23,7 @@ module Evolution {
* configuration of this widget is done trough
* Bonobo Properties
*/
- interface FolderBrowser : GNOME::Unknown {
+ interface FolderBrowser : Bonobo::Unknown {
MessageList get_message_list ();
};
};
diff --git a/mail/Makefile.am b/mail/Makefile.am
index fa903d89d9..98421cc6d4 100644
--- a/mail/Makefile.am
+++ b/mail/Makefile.am
@@ -8,7 +8,7 @@ INCLUDES = \
-I$(srcdir)/../widgets \
$(BONOBO_HTML_GNOME_CFLAGS)
-EVOLUTION_CORBA_GENERATED = \
+EVOLUTION_MAIL_CORBA_GENERATED = \
Mail.h \
Mail-common.c \
Mail-skels.c \
@@ -24,7 +24,7 @@ evolution_mail_SOURCES = \
main.c \
message-list.c \
message-list.h \
- $(EVOLUTION_CORBA_GENERATED)
+ $(EVOLUTION_MAIL_CORBA_GENERATED)
evolution_mail_LDADD = \
../widgets/e-table/libetable.a \
diff --git a/mail/folder-browser-factory.c b/mail/folder-browser-factory.c
index 0b5f9e48d9..17947b5f71 100644
--- a/mail/folder-browser-factory.c
+++ b/mail/folder-browser-factory.c
@@ -8,12 +8,13 @@
*/
#include <config.h>
#include <gnome.h>
-#include <bonobo/gnome-main.h>
-#include <bonobo/gnome-object.h>
-#include <bonobo/gnome-generic-factory.h>
+#include <bonobo/bonobo-main.h>
+#include <bonobo/bonobo-object.h>
+#include <bonobo/bonobo-generic-factory.h>
+#include "e-util/e-util.h"
-static GnomeObject *
-folder_browser_factory (GnomeGenericFactory *factory, void *closure)
+static BonoboObject *
+folder_browser_factory (BonoboGenericFactory *factory, void *closure)
{
g_error ("Fill me in!");
@@ -23,13 +24,13 @@ folder_browser_factory (GnomeGenericFactory *factory, void *closure)
void
folder_browser_factory_init (void)
{
- static GnomeGenericFactory *bonobo_folder_browser_factory = NULL;
+ static BonoboGenericFactory *bonobo_folder_browser_factory = NULL;
if (bonobo_folder_browser_factory != NULL)
return;
bonobo_folder_browser_factory =
- gnome_generic_factory_new (
+ bonobo_generic_factory_new (
"Evolution:FolderBrowser:1.0",
folder_browser_factory, NULL);
diff --git a/mail/folder-browser.c b/mail/folder-browser.c
index 63cf7566fb..880ae59a65 100644
--- a/mail/folder-browser.c
+++ b/mail/folder-browser.c
@@ -42,7 +42,7 @@ folder_browser_set_uri (FolderBrowser *folder_browser, const char *uri)
}
static void
-folder_browser_property_changed (GnomePropertyBag *properties,
+folder_browser_property_changed (BonoboPropertyBag *properties,
const char *name,
const char *type,
gpointer old_value,
@@ -62,9 +62,9 @@ folder_browser_init (GtkObject *object)
{
FolderBrowser *fb = FOLDER_BROWSER (object);
- fb->properties = gnome_property_bag_new ();
+ fb->properties = bonobo_property_bag_new ();
- gnome_property_bag_add (
+ bonobo_property_bag_add (
fb->properties, PROPERTY_FOLDER_URI, "string",
NULL, NULL, _("The URI that the Folder Browser will display", 0);
diff --git a/mail/folder-browser.h b/mail/folder-browser.h
index a81585e3ab..b3355518f7 100644
--- a/mail/folder-browser.h
+++ b/mail/folder-browser.h
@@ -13,7 +13,7 @@
typedef struct {
GtkTable parent;
- GnomePropertyBag *properties;
+ BonoboPropertyBag *properties;
/*
* The current URI being displayed by the FolderBrowser
diff --git a/mail/mail-component.c b/mail/mail-component.c
index 764be4be38..d1fca42e65 100644
--- a/mail/mail-component.c
+++ b/mail/mail-component.c
@@ -8,7 +8,7 @@
*/
#include <config.h>
#include <gnome.h>
-#include <bonobo/gnome-main.h>
+#include <bonobo/bonobo-main.h>
#include "e-util/e-gui-utils.h"
CORBA_Environment ev;
diff --git a/mail/main.c b/mail/main.c
index dc3ff752fd..517d6190e2 100644
--- a/mail/main.c
+++ b/mail/main.c
@@ -9,7 +9,7 @@
#include <config.h>
#include <gnome.h>
#include <libgnorba/gnorba.h>
-#include <bonobo/gnome-main.h>
+#include <bonobo/bonobo-main.h>
#include "e-util/e-gui-utils.h"
#include "main.h"
@@ -32,7 +32,7 @@ init_bonobo (int argc, char **argv)
}
}
-void
+int
main (int argc, char *argv [])
{
bindtextdomain (PACKAGE, EVOLUTION_LOCALEDIR);
diff --git a/mail/message-list.c b/mail/message-list.c
index f7c54bea04..7b7683ced0 100644
--- a/mail/message-list.c
+++ b/mail/message-list.c
@@ -9,7 +9,7 @@
*/
#include <config.h>
#include <gnome.h>
-#include <bonobo/gnome-main.h>
+#include <bonobo/bonobo-main.h>
#include "camel/camel-folder.h"
#include "e-table/e-table.h"
#include "e-table/e-table-simple.h"
@@ -40,9 +40,9 @@
#define COL_SIZE_WIDTH N_CHARS(6)
#define COL_SIZE_WIDTH_MIN 32
-#define PARENT_TYPE (gnome_object_get_type ())
+#define PARENT_TYPE (bonobo_object_get_type ())
-static GnomeObjectClass *message_list_parent_class;
+static BonoboObjectClass *message_list_parent_class;
static POA_Evolution_MessageList__vepv evolution_message_list_vepv;
/*
@@ -303,7 +303,7 @@ evolution_message_list_get_epv (void)
static void
message_list_corba_class_init (void)
{
- evolution_message_list_vepv.GNOME_Unknown_epv = gnome_object_get_epv ();
+ evolution_message_list_vepv.Bonobo_Unknown_epv = bonobo_object_get_epv ();
evolution_message_list_vepv.Evolution_MessageList_epv = evolution_message_list_get_epv ();
}
@@ -323,16 +323,16 @@ message_list_class_init (GtkObjectClass *object_class)
static void
message_list_construct (MessageList *message_list, Evolution_MessageList corba_message_list)
{
- gnome_object_construct (GNOME_OBJECT (message_list), corba_message_list);
+ bonobo_object_construct (BONOBO_OBJECT (message_list), corba_message_list);
}
static Evolution_MessageList
-create_corba_message_list (GnomeObject *object)
+create_corba_message_list (BonoboObject *object)
{
POA_Evolution_MessageList *servant;
CORBA_Environment ev;
- servant = (POA_Evolution_MessageList *) g_new0 (GnomeObjectServant, 1);
+ servant = (POA_Evolution_MessageList *) g_new0 (BonoboObjectServant, 1);
servant->vepv = &evolution_message_list_vepv;
CORBA_exception_init (&ev);
@@ -344,10 +344,10 @@ create_corba_message_list (GnomeObject *object)
}
CORBA_exception_free (&ev);
- return (Evolution_MessageList) gnome_object_activate_servant (object, servant);
+ return (Evolution_MessageList) bonobo_object_activate_servant (object, servant);
}
-GnomeObject *
+BonoboObject *
message_list_new (void)
{
Evolution_MessageList corba_object;
@@ -355,7 +355,7 @@ message_list_new (void)
message_list = gtk_type_new (message_list_get_type ());
- corba_object = create_corba_message_list (GNOME_OBJECT (message_list));
+ corba_object = create_corba_message_list (BONOBO_OBJECT (message_list));
if (corba_object == CORBA_OBJECT_NIL){
gtk_object_destroy (GTK_OBJECT (message_list));
return NULL;
@@ -363,7 +363,7 @@ message_list_new (void)
message_list_construct (message_list, corba_object);
- return GNOME_OBJECT (message_list);
+ return BONOBO_OBJECT (message_list);
}
void
diff --git a/mail/message-list.h b/mail/message-list.h
index 44ba575a51..ee1233e922 100644
--- a/mail/message-list.h
+++ b/mail/message-list.h
@@ -1,8 +1,8 @@
#ifndef _MESSAGE_LIST_H_
#define _MESSAGE_LIST_H_
-#include <bonobo/gnome-main.h>
-#include <bonobo/gnome-object.h>
+#include <bonobo/bonobo-main.h>
+#include <bonobo/bonobo-object.h>
#include "camel/camel-folder.h"
#define MESSAGE_LIST_TYPE (message_list_get_type ())
@@ -29,7 +29,7 @@ enum {
};
typedef struct {
- GnomeObject parent;
+ BonoboObject parent;
ETableModel *table_model;
ETableHeader *header_model;
@@ -48,11 +48,11 @@ typedef struct {
} MessageList;
typedef struct {
- GnomeObjectClass parent_class;
+ BonoboObjectClass parent_class;
} MessageListClass;
GtkType message_list_get_type (void);
-GnomeObject *message_list_new (void);
+BonoboObject *message_list_new (void);
void message_list_set_folder (MessageList *message_list,
CamelFolder *camel_folder);
GtkWidget *message_list_get_widget (MessageList *message_list);
diff --git a/shell/Evolution.idl b/shell/Evolution.idl
index 936f60633e..51b083c5d7 100644
--- a/shell/Evolution.idl
+++ b/shell/Evolution.idl
@@ -6,27 +6,23 @@
*
* (C) 2000 Helix Code, Inc.
*/
-#include <bonobo.idl>
+#include <Bonobo.idl>
-module GNOME {
-
- module Evolution {
-
- interface Shell : GNOME::Unknown {
- enum NewType {
- APPOINTMENT,
- MEETING_REQUEST,
- TASK,
- TASK_REQUEST,
- CONTACT,
- MAIL_MESSAGE,
- DISTRIBUTION_LIST,
- JOURNAL_ENTRY,
- NOTE
- };
-
- void new (in NewType type);
+module Evolution {
+ interface Shell : Bonobo::Unknown {
+ enum NewType {
+ APPOINTMENT,
+ MEETING_REQUEST,
+ TASK,
+ TASK_REQUEST,
+ CONTACT,
+ MAIL_MESSAGE,
+ DISTRIBUTION_LIST,
+ JOURNAL_ENTRY,
+ NOTE
};
+
+ void new (in NewType type);
};
};
diff --git a/shell/Makefile.am b/shell/Makefile.am
index 1aea62ce1e..b9a466b21c 100644
--- a/shell/Makefile.am
+++ b/shell/Makefile.am
@@ -35,7 +35,7 @@ evolution_SOURCES = \
Evolution-impl.o: Evolution.h
-$(EVOOLUTION_CORBA_GENERATED): Evolution.idl
+$(EVOLUTION_CORBA_GENERATED): Evolution.idl
orbit-idl -I`$(GNOME_CONFIG) --datadir`/idl -I$(srcdir) $(srcdir)/Evolution.idl
evolution_LDADD = \
diff --git a/shell/e-shell-view-menu.c b/shell/e-shell-view-menu.c
index 41129ec5f3..8e8231d774 100644
--- a/shell/e-shell-view-menu.c
+++ b/shell/e-shell-view-menu.c
@@ -215,13 +215,13 @@ static GnomeUIInfo esv_menu [] = {
void
e_shell_view_setup_menus (EShellView *eshell_view)
{
- GnomeUIHandlerMenuItem *list;
+ BonoboUIHandlerMenuItem *list;
- eshell_view->uih = gnome_ui_handler_new ();
- gnome_ui_handler_set_app (eshell_view->uih, GNOME_APP (eshell_view));
- gnome_ui_handler_create_menubar (eshell_view->uih);
+ eshell_view->uih = bonobo_ui_handler_new ();
+ bonobo_ui_handler_set_app (eshell_view->uih, GNOME_APP (eshell_view));
+ bonobo_ui_handler_create_menubar (eshell_view->uih);
- list = gnome_ui_handler_menu_parse_uiinfo_list_with_data (esv_menu, eshell_view);
- gnome_ui_handler_menu_add_list (eshell_view->uih, "/", list);
- gnome_ui_handler_menu_free_list (list);
+ list = bonobo_ui_handler_menu_parse_uiinfo_list_with_data (esv_menu, eshell_view);
+ bonobo_ui_handler_menu_add_list (eshell_view->uih, "/", list);
+ bonobo_ui_handler_menu_free_list (list);
}
diff --git a/shell/e-shell-view.h b/shell/e-shell-view.h
index b8737a5fc8..5f5c5d39c6 100644
--- a/shell/e-shell-view.h
+++ b/shell/e-shell-view.h
@@ -1,8 +1,8 @@
#ifndef E_SHELL_VIEW_H
#define E_SHELL_VIEW_H
-#include <bonobo/gnome-object.h>
-#include <bonobo/gnome-ui-handler.h>
+#include <bonobo/bonobo-object.h>
+#include <bonobo/bonobo-ui-handler.h>
#include "e-shell.h"
#define E_SHELL_VIEW_TYPE (e_shell_view_get_type ())
@@ -18,7 +18,7 @@ struct _EShellView {
EShell *eshell;
/* Our user interface handler */
- GnomeUIHandler *uih;
+ BonoboUIHandler *uih;
EFolder *efolder;
diff --git a/shell/e-shell.c b/shell/e-shell.c
index 9be32ba3c1..cd4be67bc6 100644
--- a/shell/e-shell.c
+++ b/shell/e-shell.c
@@ -14,10 +14,10 @@
#include "e-util/e-util.h"
#include "e-shell.h"
-#define PARENT_TYPE (gnome_object_get_type ())
+#define PARENT_TYPE (bonobo_object_get_type ())
-static GnomeObjectClass *e_shell_parent_class;
-POA_GNOME_Evolution_Shell__vepv eshell_vepv;
+static BonoboObjectClass *e_shell_parent_class;
+POA_Evolution_Shell__vepv eshell_vepv;
GtkType e_shell_get_type (void);
@@ -77,45 +77,45 @@ e_shell_new_note (EShell *eshell)
static void
EShell_cmd_new (PortableServer_Servant servant,
- const GNOME_Evolution_Shell_NewType type,
+ const Evolution_Shell_NewType type,
CORBA_Environment *ev)
{
- EShell *eshell = E_SHELL (gnome_object_from_servant (servant));
+ EShell *eshell = E_SHELL (bonobo_object_from_servant (servant));
switch (type){
- case GNOME_Evolution_Shell_APPOINTMENT:
+ case Evolution_Shell_APPOINTMENT:
e_shell_new_appointment (eshell);
break;
- case GNOME_Evolution_Shell_MEETING_REQUEST:
+ case Evolution_Shell_MEETING_REQUEST:
e_shell_new_meeting_request (eshell);
break;
- case GNOME_Evolution_Shell_TASK:
+ case Evolution_Shell_TASK:
e_shell_new_task (eshell);
break;
- case GNOME_Evolution_Shell_TASK_REQUEST:
+ case Evolution_Shell_TASK_REQUEST:
e_shell_new_task_request (eshell);
break;
- case GNOME_Evolution_Shell_CONTACT:
+ case Evolution_Shell_CONTACT:
e_shell_new_contact (eshell);
break;
- case GNOME_Evolution_Shell_MAIL_MESSAGE:
+ case Evolution_Shell_MAIL_MESSAGE:
e_shell_new_mail_message (eshell);
break;
- case GNOME_Evolution_Shell_DISTRIBUTION_LIST:
+ case Evolution_Shell_DISTRIBUTION_LIST:
e_shell_new_distribution_list (eshell);
break;
- case GNOME_Evolution_Shell_JOURNAL_ENTRY:
+ case Evolution_Shell_JOURNAL_ENTRY:
e_shell_new_journal_entry (eshell);
break;
- case GNOME_Evolution_Shell_NOTE:
+ case Evolution_Shell_NOTE:
e_shell_new_note (eshell);
break;
@@ -123,12 +123,12 @@ EShell_cmd_new (PortableServer_Servant servant,
}
}
-static POA_GNOME_Evolution_Shell__epv *
+static POA_Evolution_Shell__epv *
e_shell_get_epv (void)
{
- POA_GNOME_Evolution_Shell__epv *epv;
+ POA_Evolution_Shell__epv *epv;
- epv = g_new0 (POA_GNOME_Evolution_Shell__epv, 1);
+ epv = g_new0 (POA_Evolution_Shell__epv, 1);
epv->new = EShell_cmd_new;
@@ -138,8 +138,8 @@ e_shell_get_epv (void)
static void
init_e_shell_corba_class (void)
{
- eshell_vepv.GNOME_Unknown_epv = gnome_object_get_epv ();
- eshell_vepv.GNOME_Evolution_Shell_epv = e_shell_get_epv ();
+ eshell_vepv.Bonobo_Unknown_epv = bonobo_object_get_epv ();
+ eshell_vepv.Evolution_Shell_epv = e_shell_get_epv ();
}
static void
@@ -199,17 +199,17 @@ e_shell_quit (EShell *eshell)
}
static CORBA_Object
-create_corba_eshell (GnomeObject *object)
+create_corba_eshell (BonoboObject *object)
{
- POA_GNOME_Evolution_Shell *servant;
+ POA_Evolution_Shell *servant;
CORBA_Environment ev;
- servant = (POA_GNOME_Evolution_Shell *)g_new0 (GnomeObjectServant, 1);
+ servant = (POA_Evolution_Shell *)g_new0 (BonoboObjectServant, 1);
servant->vepv = &eshell_vepv;
CORBA_exception_init (&ev);
- POA_GNOME_Evolution_Shell__init ((PortableServer_Servant) servant, &ev);
+ POA_Evolution_Shell__init ((PortableServer_Servant) servant, &ev);
if (ev._major != CORBA_NO_EXCEPTION){
CORBA_exception_free (&ev);
g_free (servant);
@@ -218,7 +218,7 @@ create_corba_eshell (GnomeObject *object)
CORBA_exception_free (&ev);
- return gnome_object_activate_servant (object, servant);
+ return bonobo_object_activate_servant (object, servant);
}
static void
@@ -297,20 +297,20 @@ e_shell_init (GtkObject *object)
}
static void
-e_shell_construct (EShell *eshell, GNOME_Evolution_Shell corba_eshell)
+e_shell_construct (EShell *eshell, Evolution_Shell corba_eshell)
{
- gnome_object_construct (GNOME_OBJECT (eshell), corba_eshell);
+ bonobo_object_construct (BONOBO_OBJECT (eshell), corba_eshell);
}
EShell *
e_shell_new (void)
{
- GNOME_Evolution_Shell corba_eshell;
+ Evolution_Shell corba_eshell;
EShell *eshell;
eshell = gtk_type_new (e_shell_get_type ());
- corba_eshell = create_corba_eshell (GNOME_OBJECT (eshell));
+ corba_eshell = create_corba_eshell (BONOBO_OBJECT (eshell));
if (corba_eshell == CORBA_OBJECT_NIL){
gtk_object_destroy (GTK_OBJECT (eshell));
return NULL;
diff --git a/shell/e-shell.h b/shell/e-shell.h
index b2778f0444..64de044fb4 100644
--- a/shell/e-shell.h
+++ b/shell/e-shell.h
@@ -1,7 +1,7 @@
#ifndef E_SHELL_H
#define E_SHELL_H
-#include <bonobo/gnome-object.h>
+#include <bonobo/bonobo-object.h>
#include "evolution.h"
#include "e-folder.h"
#include "e-shortcut.h"
@@ -16,7 +16,7 @@
#define E_IS_SHELL_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), E_SHELL_TYPE))
struct _EShell {
- GnomeObject base_object;
+ BonoboObject base_object;
/* A list of EShellViews */
GSList *views;
@@ -35,7 +35,7 @@ struct _EShell {
};
typedef struct {
- GnomeObjectClass parent_class;
+ BonoboObjectClass parent_class;
} EShellClass;
EShell *e_shell_new (void);
diff --git a/shell/main.c b/shell/main.c
index 1d30bbad7d..1d6d8bed7c 100644
--- a/shell/main.c
+++ b/shell/main.c
@@ -8,7 +8,7 @@
#include <config.h>
#include <gnome.h>
#include <libgnorba/gnorba.h>
-#include <bonobo/gnome-bonobo.h>
+#include <bonobo.h>
#include <e-util/e-gui-utils.h>
#include <e-util/e-cursors.h>
#include <glade/glade.h>
diff --git a/calendar/cal-client/cal-listener.c b/calendar/cal-client/cal-listener.c
index 8583a689c8..a5a37a12d9 100644
--- a/calendar/cal-client/cal-listener.c
+++ b/calendar/cal-client/cal-listener.c
@@ -51,7 +51,7 @@ static POA_GNOME_Calendar_Listener__vepv cal_listener_vepv;
static guint cal_listener_signals[LAST_SIGNAL];
-static GnomeObjectClass *parent_class;
+static BonoboObjectClass *parent_class;
@@ -81,7 +81,7 @@ cal_listener_get_type (void)
(GtkClassInitFunc) NULL
};
- cal_listener_type = gtk_type_unique (gnome_object_get_type (), &cal_listener_info);
+ cal_listener_type = gtk_type_unique (bonobo_object_get_type (), &cal_listener_info);
}
return cal_listener_type;
@@ -91,7 +91,7 @@ cal_listener_get_type (void)
static void
init_cal_listener_corba_class (void)
{
- cal_listener_vepv.GNOME_Unknown_epv = gnome_object_get_epv ();
+ cal_listener_vepv.Bonobo_Unknown_epv = bonobo_object_get_epv ();
cal_listener_vepv.GNOME_Calendar_Listener_epv = cal_listener_get_epv ();
}
@@ -103,7 +103,7 @@ cal_listener_class_init (CalListenerClass *class)
object_class = (GtkObjectClass *) class;
- parent_class = gtk_type_class (gnome_object_get_type ());
+ parent_class = gtk_type_class (bonobo_object_get_type ());
cal_listener_signals[CAL_LOADED] =
gtk_signal_new ("cal_loaded",
@@ -227,7 +227,7 @@ Listener_cal_loaded (PortableServer_Servant servant,
GNOME_Calendar_Cal cal_copy;
CalListenerLoadStatus load_status;
- listener = CAL_LISTENER (gnome_object_from_servant (servant));
+ listener = CAL_LISTENER (bonobo_object_from_servant (servant));
priv = listener->priv;
if (priv->cal != CORBA_OBJECT_NIL) {
@@ -273,7 +273,7 @@ Listener_obj_added (PortableServer_Servant servant,
{
CalListener *listener;
- listener = CAL_LISTENER (gnome_object_from_servant (servant));
+ listener = CAL_LISTENER (bonobo_object_from_servant (servant));
gtk_signal_emit (GTK_OBJECT (listener), cal_listener_signals[OBJ_ADDED],
calobj);
}
@@ -286,7 +286,7 @@ Listener_obj_removed (PortableServer_Servant servant,
{
CalListener *listener;
- listener = CAL_LISTENER (gnome_object_from_servant (servant));
+ listener = CAL_LISTENER (bonobo_object_from_servant (servant));
gtk_signal_emit (GTK_OBJECT (listener), cal_listener_signals[OBJ_REMOVED],
uid);
}
@@ -299,7 +299,7 @@ Listener_obj_changed (PortableServer_Servant servant,
{
CalListener *listener;
- listener = CAL_LISTENER (gnome_object_from_servant (servant));
+ listener = CAL_LISTENER (bonobo_object_from_servant (servant));
gtk_signal_emit (GTK_OBJECT (listener), cal_listener_signals[OBJ_CHANGED],
calobj);
}
@@ -344,13 +344,13 @@ cal_listener_construct (CalListener *listener, GNOME_Calendar_Listener corba_lis
g_return_val_if_fail (listener != NULL, NULL);
g_return_val_if_fail (IS_CAL_LISTENER (listener), NULL);
- gnome_object_construct (GNOME_OBJECT (listener), corba_listener);
+ bonobo_object_construct (BONOBO_OBJECT (listener), corba_listener);
return listener;
}
/**
* cal_listener_corba_object_create:
* @object: #GnomeObject that will wrap the CORBA object.
*
* Creates and activates the CORBA object that is wrapped by the specified
* calendar listener @object.
@@ -359,7 +359,7 @@ cal_listener_construct (CalListener *listener, GNOME_Calendar_Listener corba_lis
* failure.
**/
GNOME_Calendar_Listener
-cal_listener_corba_object_create (GnomeObject *object)
+cal_listener_corba_object_create (BonoboObject *object)
{
POA_GNOME_Calendar_Listener *servant;
CORBA_Environment ev;
@@ -367,7 +367,7 @@ cal_listener_corba_object_create (GnomeObject *object)
g_return_val_if_fail (object != NULL, CORBA_OBJECT_NIL);
g_return_val_if_fail (IS_CAL_LISTENER (object), CORBA_OBJECT_NIL);
- servant = (POA_GNOME_Calendar_Listener *) g_new0 (GnomeObjectServant, 1);
+ servant = (POA_GNOME_Calendar_Listener *) g_new0 (BonoboObjectServant, 1);
servant->vepv = &cal_listener_vepv;
CORBA_exception_init (&ev);
@@ -379,7 +379,7 @@ cal_listener_corba_object_create (GnomeObject *object)
}
CORBA_exception_free (&ev);
- return (GNOME_Calendar_Listener) gnome_object_activate_servant (object, servant);
+ return (GNOME_Calendar_Listener) bonobo_object_activate_servant (object, servant);
}
/**
@@ -401,7 +401,7 @@ cal_listener_new (void)
listener = gtk_type_new (CAL_LISTENER_TYPE);
- corba_listener = cal_listener_corba_object_create (GNOME_OBJECT (listener));
+ corba_listener = cal_listener_corba_object_create (BONOBO_OBJECT (listener));
CORBA_exception_init (&ev);
result = CORBA_Object_is_nil (corba_listener, &ev);
@@ -344,13 +344,13 @@ cal_listener_construct (CalListener *listener, GNOME_Calendar_Listener corba_lis
/**
* cal_listener_corba_object_create:
- * @object: #GnomeObject that will wrap the CORBA object.
+ * @object: #BonoboObject that will wrap the CORBA object.
*
* Creates and activates the CORBA object that is wrapped by the specified
diff --git a/calendar/cal-factory.c b/calendar/cal-factory.c
index aef37e29cd..022fb183f1 100644
--- a/calendar/cal-factory.c
+++ b/calendar/cal-factory.c
@@ -41,7 +41,7 @@ static void cal_factory_destroy (GtkObject *object);
static POA_GNOME_Calendar_CalFactory__vepv cal_factory_vepv;
-static GnomeObjectClass *parent_class;
+static BonoboObjectClass *parent_class;
@@ -71,7 +71,7 @@ cal_factory_get_type (void)
(GtkClassInitFunc) NULL
};
- cal_factory_type = gtk_type_unique (gnome_object_get_type (), &cal_factory_info);
+ cal_factory_type = gtk_type_unique (bonobo_object_get_type (), &cal_factory_info);
}
return cal_factory_type;
@@ -81,7 +81,7 @@ cal_factory_get_type (void)
static void
init_cal_factory_corba_class (void)
{
- cal_factory_vepv.GNOME_Unknown_epv = gnome_object_get_epv ();
+ cal_factory_vepv.Bonobo_Unknown_epv = bonobo_object_get_epv ();
cal_factory_vepv.GNOME_Calendar_CalFactory_epv = cal_factory_get_epv ();
}
@@ -93,7 +93,7 @@ cal_factory_class_init (CalFactoryClass *class)
object_class = (GtkObjectClass *) class;
- parent_class = gtk_type_class (gnome_object_get_type ());
+ parent_class = gtk_type_class (bonobo_object_get_type ());
object_class->destroy = cal_factory_destroy;
@@ -165,7 +165,7 @@ CalFactory_load (PortableServer_Servant servant,
CORBA_Environment ev2;
gboolean result;
- factory = CAL_FACTORY (gnome_object_from_servant (servant));
+ factory = CAL_FACTORY (bonobo_object_from_servant (servant));
priv = factory->priv;
CORBA_exception_init (&ev2);
@@ -194,7 +194,7 @@ CalFactory_create (PortableServer_Servant servant,
CalFactory *factory;
CalFactoryPrivate *priv;
- factory = CAL_FACTORY (gnome_object_from_servant (servant));
+ factory = CAL_FACTORY (bonobo_object_from_servant (servant));
priv = factory->priv;
cal_factory_create (factory, uri, listener);
@@ -309,7 +309,7 @@ add_calendar_client (CalFactory *factory, CalBackend *backend, GNOME_Calendar_Li
CORBA_exception_init (&ev);
GNOME_Calendar_Listener_cal_loaded (listener,
GNOME_Calendar_Listener_SUCESSS,
- gnome_object_corba_objref (GNOME_OBJECT (cal)),
+ bonobo_object_corba_objref (BONOBO_OBJECT (cal)),
&ev);
if (ev._major != CORBA_NO_EXCEPTION) {
@@ -395,13 +395,13 @@ cal_factory_construct (CalFactory *factory, GNOME_Calendar_CalFactory corba_fact
g_return_val_if_fail (factory != NULL, NULL);
g_return_val_if_fail (IS_CAL_FACTORY (factory), NULL);
- gnome_object_construct (GNOME_OBJECT (factory), corba_factory);
+ bonobo_object_construct (BONOBO_OBJECT (factory), corba_factory);
return factory;
}
/**
* cal_factory_corba_object_create:
* @object: #GnomeObject that will wrap the CORBA object.
*
* Creates and activates the CORBA object that is wrapped by the specified
* calendar factory @object.
@@ -410,7 +410,7 @@ cal_factory_construct (CalFactory *factory, GNOME_Calendar_CalFactory corba_fact
* failure.
**/
GNOME_Calendar_CalFactory
-cal_factory_corba_object_create (GnomeObject *object)
+cal_factory_corba_object_create (BonoboObject *object)
{
POA_GNOME_Calendar_CalFactory *servant;
CORBA_Environment ev;
@@ -418,7 +418,7 @@ cal_factory_corba_object_create (GnomeObject *object)
g_return_val_if_fail (object != NULL, CORBA_OBJECT_NIL);
g_return_val_if_fail (IS_CAL_FACTORY (object), CORBA_OBJECT_NIL);
- servant = (POA_GNOME_Calendar_CalFactory *) g_new0 (GnomeObjectServant, 1);
+ servant = (POA_GNOME_Calendar_CalFactory *) g_new0 (BonoboObjectServant, 1);
servant->vepv = &cal_factory_vepv;
CORBA_exception_init (&ev);
@@ -432,7 +432,7 @@ cal_factory_corba_object_create (GnomeObject *object)
}
CORBA_exception_free (&ev);
- return (GNOME_Calendar_CalFactory) gnome_object_activate_servant (object, servant);
+ return (GNOME_Calendar_CalFactory) bonobo_object_activate_servant (object, servant);
}
/**
@@ -454,7 +454,7 @@ cal_factory_new (void)
factory = gtk_type_new (CAL_FACTORY_TYPE);
- corba_factory = cal_factory_corba_object_create (GNOME_OBJECT (factory));
+ corba_factory = cal_factory_corba_object_create (BONOBO_OBJECT (factory));
CORBA_exception_init (&ev);
retval = CORBA_Object_is_nil (corba_factory, &ev);
@@ -395,13 +395,13 @@ cal_factory_construct (CalFactory *factory, GNOME_Calendar_CalFactory corba_fact
/**
* cal_factory_corba_object_create:
- * @object: #GnomeObject that will wrap the CORBA object.
+ * @object: #BonoboObject that will wrap the CORBA object.
*
* Creates and activates the CORBA object that is wrapped by the specified
diff --git a/calendar/cal-listener.c b/calendar/cal-listener.c
index 8583a689c8..a5a37a12d9 100644
--- a/calendar/cal-listener.c
+++ b/calendar/cal-listener.c
@@ -51,7 +51,7 @@ static POA_GNOME_Calendar_Listener__vepv cal_listener_vepv;
static guint cal_listener_signals[LAST_SIGNAL];
-static GnomeObjectClass *parent_class;
+static BonoboObjectClass *parent_class;
@@ -81,7 +81,7 @@ cal_listener_get_type (void)
(GtkClassInitFunc) NULL
};
- cal_listener_type = gtk_type_unique (gnome_object_get_type (), &cal_listener_info);
+ cal_listener_type = gtk_type_unique (bonobo_object_get_type (), &cal_listener_info);
}
return cal_listener_type;
@@ -91,7 +91,7 @@ cal_listener_get_type (void)
static void
init_cal_listener_corba_class (void)
{
- cal_listener_vepv.GNOME_Unknown_epv = gnome_object_get_epv ();
+ cal_listener_vepv.Bonobo_Unknown_epv = bonobo_object_get_epv ();
cal_listener_vepv.GNOME_Calendar_Listener_epv = cal_listener_get_epv ();
}
@@ -103,7 +103,7 @@ cal_listener_class_init (CalListenerClass *class)
object_class = (GtkObjectClass *) class;
- parent_class = gtk_type_class (gnome_object_get_type ());
+ parent_class = gtk_type_class (bonobo_object_get_type ());
cal_listener_signals[CAL_LOADED] =
gtk_signal_new ("cal_loaded",
@@ -227,7 +227,7 @@ Listener_cal_loaded (PortableServer_Servant servant,
GNOME_Calendar_Cal cal_copy;
CalListenerLoadStatus load_status;
- listener = CAL_LISTENER (gnome_object_from_servant (servant));
+ listener = CAL_LISTENER (bonobo_object_from_servant (servant));
priv = listener->priv;
if (priv->cal != CORBA_OBJECT_NIL) {
@@ -273,7 +273,7 @@ Listener_obj_added (PortableServer_Servant servant,
{
CalListener *listener;
- listener = CAL_LISTENER (gnome_object_from_servant (servant));
+ listener = CAL_LISTENER (bonobo_object_from_servant (servant));
gtk_signal_emit (GTK_OBJECT (listener), cal_listener_signals[OBJ_ADDED],
calobj);
}
@@ -286,7 +286,7 @@ Listener_obj_removed (PortableServer_Servant servant,
{
CalListener *listener;
- listener = CAL_LISTENER (gnome_object_from_servant (servant));
+ listener = CAL_LISTENER (bonobo_object_from_servant (servant));
gtk_signal_emit (GTK_OBJECT (listener), cal_listener_signals[OBJ_REMOVED],
uid);
}
@@ -299,7 +299,7 @@ Listener_obj_changed (PortableServer_Servant servant,
{
CalListener *listener;
- listener = CAL_LISTENER (gnome_object_from_servant (servant));
+ listener = CAL_LISTENER (bonobo_object_from_servant (servant));
gtk_signal_emit (GTK_OBJECT (listener), cal_listener_signals[OBJ_CHANGED],
calobj);
}
@@ -344,13 +344,13 @@ cal_listener_construct (CalListener *listener, GNOME_Calendar_Listener corba_lis
g_return_val_if_fail (listener != NULL, NULL);
g_return_val_if_fail (IS_CAL_LISTENER (listener), NULL);
- gnome_object_construct (GNOME_OBJECT (listener), corba_listener);
+ bonobo_object_construct (BONOBO_OBJECT (listener), corba_listener);
return listener;
}
/**
* cal_listener_corba_object_create:
* @object: #GnomeObject that will wrap the CORBA object.
*
* Creates and activates the CORBA object that is wrapped by the specified
* calendar listener @object.
@@ -359,7 +359,7 @@ cal_listener_construct (CalListener *listener, GNOME_Calendar_Listener corba_lis
* failure.
**/
GNOME_Calendar_Listener
-cal_listener_corba_object_create (GnomeObject *object)
+cal_listener_corba_object_create (BonoboObject *object)
{
POA_GNOME_Calendar_Listener *servant;
CORBA_Environment ev;
@@ -367,7 +367,7 @@ cal_listener_corba_object_create (GnomeObject *object)
g_return_val_if_fail (object != NULL, CORBA_OBJECT_NIL);
g_return_val_if_fail (IS_CAL_LISTENER (object), CORBA_OBJECT_NIL);
- servant = (POA_GNOME_Calendar_Listener *) g_new0 (GnomeObjectServant, 1);
+ servant = (POA_GNOME_Calendar_Listener *) g_new0 (BonoboObjectServant, 1);
servant->vepv = &cal_listener_vepv;
CORBA_exception_init (&ev);
@@ -379,7 +379,7 @@ cal_listener_corba_object_create (GnomeObject *object)
}
CORBA_exception_free (&ev);
- return (GNOME_Calendar_Listener) gnome_object_activate_servant (object, servant);
+ return (GNOME_Calendar_Listener) bonobo_object_activate_servant (object, servant);
}
/**
@@ -401,7 +401,7 @@ cal_listener_new (void)
listener = gtk_type_new (CAL_LISTENER_TYPE);
- corba_listener = cal_listener_corba_object_create (GNOME_OBJECT (listener));
+ corba_listener = cal_listener_corba_object_create (BONOBO_OBJECT (listener));
CORBA_exception_init (&ev);
result = CORBA_Object_is_nil (corba_listener, &ev);
@@ -344,13 +344,13 @@ cal_listener_construct (CalListener *listener, GNOME_Calendar_Listener corba_lis
/**
* cal_listener_corba_object_create:
- * @object: #GnomeObject that will wrap the CORBA object.
+ * @object: #BonoboObject that will wrap the CORBA object.
*
* Creates and activates the CORBA object that is wrapped by the specified
diff --git a/calendar/cal.c b/calendar/cal.c
index f855def92b..2ddef9df37 100644
--- a/calendar/cal.c
+++ b/calendar/cal.c
@@ -42,7 +42,7 @@ static void cal_destroy (GtkObject *object);
static POA_GNOME_Calendar_Cal__vepv cal_vepv;
-static GnomeObjectClass *parent_class;
+static BonoboObjectClass *parent_class;
@@ -72,7 +72,7 @@ cal_get_type (void)
(GtkClassInitFunc) NULL
};
- cal_type = gtk_type_unique (GNOME_OBJECT_TYPE, &cal_info);
+ cal_type = gtk_type_unique (BONOBO_OBJECT_TYPE, &cal_info);
}
return cal_type;
@@ -82,7 +82,7 @@ cal_get_type (void)
static void
init_cal_corba_class (void)
{
- cal_vepv.GNOME_Unknown_epv = gnome_object_get_epv ();
+ cal_vepv.Bonobo_Unknown_epv = bonobo_object_get_epv ();
cal_vepv.GNOME_Calendar_Cal_epv = cal_get_epv ();
}
@@ -94,7 +94,7 @@ cal_class_init (CalClass *class)
object_class = (GtkObjectClass *) class;
- parent_class = gtk_type_class (GNOME_OBJECT_TYPE);
+ parent_class = gtk_type_class (BONOBO_OBJECT_TYPE);
object_class->destroy = cal_destroy;
@@ -155,7 +155,7 @@ Cal_get_uri (PortableServer_Servant servant,
char *str_uri;
CORBA_char *str_uri_copy;
- cal = CAL (gnome_object_from_servant (servant));
+ cal = CAL (bonobo_object_from_servant (servant));
priv = cal->priv;
uri = cal_backend_get_uri (priv->backend);
@@ -230,13 +230,13 @@ cal_construct (Cal *cal,
priv->backend = backend;
- gnome_object_construct (GNOME_OBJECT (cal), corba_cal);
+ bonobo_object_construct (BONOBO_OBJECT (cal), corba_cal);
return cal;
}
/**
* cal_corba_object_create:
* @object: #GnomeObject that will wrap the CORBA object.
*
* Creates and activates the CORBA object that is wrapped by the specified
* calendar client interface @object.
@@ -245,7 +245,7 @@ cal_construct (Cal *cal,
* failure.
**/
GNOME_Calendar_Cal
-cal_corba_object_create (GnomeObject *object)
+cal_corba_object_create (BonoboObject *object)
{
POA_GNOME_Calendar_Cal *servant;
CORBA_Environment ev;
@@ -253,7 +253,7 @@ cal_corba_object_create (GnomeObject *object)
g_return_val_if_fail (object != NULL, CORBA_OBJECT_NIL);
g_return_val_if_fail (IS_CAL (object), CORBA_OBJECT_NIL);
- servant = (POA_GNOME_Calendar_Cal *) g_new0 (GnomeObjectServant, 1);
+ servant = (POA_GNOME_Calendar_Cal *) g_new0 (BonoboObjectServant, 1);
servant->vepv = &cal_vepv;
CORBA_exception_init (&ev);
@@ -266,7 +266,7 @@ cal_corba_object_create (GnomeObject *object)
}
CORBA_exception_free (&ev);
- return (GNOME_Calendar_Cal) gnome_object_activate_servant (object, servant);
+ return (GNOME_Calendar_Cal) bonobo_object_activate_servant (object, servant);
}
/**
@@ -292,7 +292,7 @@ cal_new (CalBackend *backend, GNOME_Calendar_Listener listener)
g_return_val_if_fail (IS_CAL_BACKEND (backend), NULL);
cal = CAL (gtk_type_new (CAL_TYPE));
- corba_cal = cal_corba_object_create (GNOME_OBJECT (cal));
+ corba_cal = cal_corba_object_create (BONOBO_OBJECT (cal));
CORBA_exception_init (&ev);
ret = CORBA_Object_is_nil ((CORBA_Object) corba_cal, &ev);
@@ -230,13 +230,13 @@ cal_construct (Cal *cal,
/**
* cal_corba_object_create:
- * @object: #GnomeObject that will wrap the CORBA object.
+ * @object: #BonoboObject that will wrap the CORBA object.
*
* Creates and activates the CORBA object that is wrapped by the specified
diff --git a/calendar/pcs/cal-factory.c b/calendar/pcs/cal-factory.c
index aef37e29cd..022fb183f1 100644
--- a/calendar/pcs/cal-factory.c
+++ b/calendar/pcs/cal-factory.c
@@ -41,7 +41,7 @@ static void cal_factory_destroy (GtkObject *object);
static POA_GNOME_Calendar_CalFactory__vepv cal_factory_vepv;
-static GnomeObjectClass *parent_class;
+static BonoboObjectClass *parent_class;
@@ -71,7 +71,7 @@ cal_factory_get_type (void)
(GtkClassInitFunc) NULL
};
- cal_factory_type = gtk_type_unique (gnome_object_get_type (), &cal_factory_info);
+ cal_factory_type = gtk_type_unique (bonobo_object_get_type (), &cal_factory_info);
}
return cal_factory_type;
@@ -81,7 +81,7 @@ cal_factory_get_type (void)
static void
init_cal_factory_corba_class (void)
{
- cal_factory_vepv.GNOME_Unknown_epv = gnome_object_get_epv ();
+ cal_factory_vepv.Bonobo_Unknown_epv = bonobo_object_get_epv ();
cal_factory_vepv.GNOME_Calendar_CalFactory_epv = cal_factory_get_epv ();
}
@@ -93,7 +93,7 @@ cal_factory_class_init (CalFactoryClass *class)
object_class = (GtkObjectClass *) class;
- parent_class = gtk_type_class (gnome_object_get_type ());
+ parent_class = gtk_type_class (bonobo_object_get_type ());
object_class->destroy = cal_factory_destroy;
@@ -165,7 +165,7 @@ CalFactory_load (PortableServer_Servant servant,
CORBA_Environment ev2;
gboolean result;
- factory = CAL_FACTORY (gnome_object_from_servant (servant));
+ factory = CAL_FACTORY (bonobo_object_from_servant (servant));
priv = factory->priv;
CORBA_exception_init (&ev2);
@@ -194,7 +194,7 @@ CalFactory_create (PortableServer_Servant servant,
CalFactory *factory;
CalFactoryPrivate *priv;
- factory = CAL_FACTORY (gnome_object_from_servant (servant));
+ factory = CAL_FACTORY (bonobo_object_from_servant (servant));
priv = factory->priv;
cal_factory_create (factory, uri, listener);
@@ -309,7 +309,7 @@ add_calendar_client (CalFactory *factory, CalBackend *backend, GNOME_Calendar_Li
CORBA_exception_init (&ev);
GNOME_Calendar_Listener_cal_loaded (listener,
GNOME_Calendar_Listener_SUCESSS,
- gnome_object_corba_objref (GNOME_OBJECT (cal)),
+ bonobo_object_corba_objref (BONOBO_OBJECT (cal)),
&ev);
if (ev._major != CORBA_NO_EXCEPTION) {
@@ -395,13 +395,13 @@ cal_factory_construct (CalFactory *factory, GNOME_Calendar_CalFactory corba_fact
g_return_val_if_fail (factory != NULL, NULL);
g_return_val_if_fail (IS_CAL_FACTORY (factory), NULL);
- gnome_object_construct (GNOME_OBJECT (factory), corba_factory);
+ bonobo_object_construct (BONOBO_OBJECT (factory), corba_factory);
return factory;
}
/**
* cal_factory_corba_object_create:
* @object: #GnomeObject that will wrap the CORBA object.
*
* Creates and activates the CORBA object that is wrapped by the specified
* calendar factory @object.
@@ -410,7 +410,7 @@ cal_factory_construct (CalFactory *factory, GNOME_Calendar_CalFactory corba_fact
* failure.
**/
GNOME_Calendar_CalFactory
-cal_factory_corba_object_create (GnomeObject *object)
+cal_factory_corba_object_create (BonoboObject *object)
{
POA_GNOME_Calendar_CalFactory *servant;
CORBA_Environment ev;
@@ -418,7 +418,7 @@ cal_factory_corba_object_create (GnomeObject *object)
g_return_val_if_fail (object != NULL, CORBA_OBJECT_NIL);
g_return_val_if_fail (IS_CAL_FACTORY (object), CORBA_OBJECT_NIL);
- servant = (POA_GNOME_Calendar_CalFactory *) g_new0 (GnomeObjectServant, 1);
+ servant = (POA_GNOME_Calendar_CalFactory *) g_new0 (BonoboObjectServant, 1);
servant->vepv = &cal_factory_vepv;
CORBA_exception_init (&ev);
@@ -432,7 +432,7 @@ cal_factory_corba_object_create (GnomeObject *object)
}
CORBA_exception_free (&ev);
- return (GNOME_Calendar_CalFactory) gnome_object_activate_servant (object, servant);
+ return (GNOME_Calendar_CalFactory) bonobo_object_activate_servant (object, servant);
}
/**
@@ -454,7 +454,7 @@ cal_factory_new (void)
factory = gtk_type_new (CAL_FACTORY_TYPE);
- corba_factory = cal_factory_corba_object_create (GNOME_OBJECT (factory));
+ corba_factory = cal_factory_corba_object_create (BONOBO_OBJECT (factory));
CORBA_exception_init (&ev);
retval = CORBA_Object_is_nil (corba_factory, &ev);
@@ -395,13 +395,13 @@ cal_factory_construct (CalFactory *factory, GNOME_Calendar_CalFactory corba_fact
/**
* cal_factory_corba_object_create:
- * @object: #GnomeObject that will wrap the CORBA object.
+ * @object: #BonoboObject that will wrap the CORBA object.
*
* Creates and activates the CORBA object that is wrapped by the specified
diff --git a/calendar/pcs/cal.c b/calendar/pcs/cal.c
index f855def92b..2ddef9df37 100644
--- a/calendar/pcs/cal.c
+++ b/calendar/pcs/cal.c
@@ -42,7 +42,7 @@ static void cal_destroy (GtkObject *object);
static POA_GNOME_Calendar_Cal__vepv cal_vepv;
-static GnomeObjectClass *parent_class;
+static BonoboObjectClass *parent_class;
@@ -72,7 +72,7 @@ cal_get_type (void)
(GtkClassInitFunc) NULL
};
- cal_type = gtk_type_unique (GNOME_OBJECT_TYPE, &cal_info);
+ cal_type = gtk_type_unique (BONOBO_OBJECT_TYPE, &cal_info);
}
return cal_type;
@@ -82,7 +82,7 @@ cal_get_type (void)
static void
init_cal_corba_class (void)
{
- cal_vepv.GNOME_Unknown_epv = gnome_object_get_epv ();
+ cal_vepv.Bonobo_Unknown_epv = bonobo_object_get_epv ();
cal_vepv.GNOME_Calendar_Cal_epv = cal_get_epv ();
}
@@ -94,7 +94,7 @@ cal_class_init (CalClass *class)
object_class = (GtkObjectClass *) class;
- parent_class = gtk_type_class (GNOME_OBJECT_TYPE);
+ parent_class = gtk_type_class (BONOBO_OBJECT_TYPE);
object_class->destroy = cal_destroy;
@@ -155,7 +155,7 @@ Cal_get_uri (PortableServer_Servant servant,
char *str_uri;
CORBA_char *str_uri_copy;
- cal = CAL (gnome_object_from_servant (servant));
+ cal = CAL (bonobo_object_from_servant (servant));
priv = cal->priv;
uri = cal_backend_get_uri (priv->backend);
@@ -230,13 +230,13 @@ cal_construct (Cal *cal,
priv->backend = backend;
- gnome_object_construct (GNOME_OBJECT (cal), corba_cal);
+ bonobo_object_construct (BONOBO_OBJECT (cal), corba_cal);
return cal;
}
/**
* cal_corba_object_create:
* @object: #GnomeObject that will wrap the CORBA object.
*
* Creates and activates the CORBA object that is wrapped by the specified
* calendar client interface @object.
@@ -245,7 +245,7 @@ cal_construct (Cal *cal,
* failure.
**/
GNOME_Calendar_Cal
-cal_corba_object_create (GnomeObject *object)
+cal_corba_object_create (BonoboObject *object)
{
POA_GNOME_Calendar_Cal *servant;
CORBA_Environment ev;
@@ -253,7 +253,7 @@ cal_corba_object_create (GnomeObject *object)
g_return_val_if_fail (object != NULL, CORBA_OBJECT_NIL);
g_return_val_if_fail (IS_CAL (object), CORBA_OBJECT_NIL);
- servant = (POA_GNOME_Calendar_Cal *) g_new0 (GnomeObjectServant, 1);
+ servant = (POA_GNOME_Calendar_Cal *) g_new0 (BonoboObjectServant, 1);
servant->vepv = &cal_vepv;
CORBA_exception_init (&ev);
@@ -266,7 +266,7 @@ cal_corba_object_create (GnomeObject *object)
}
CORBA_exception_free (&ev);
- return (GNOME_Calendar_Cal) gnome_object_activate_servant (object, servant);
+ return (GNOME_Calendar_Cal) bonobo_object_activate_servant (object, servant);
}
/**
@@ -292,7 +292,7 @@ cal_new (CalBackend *backend, GNOME_Calendar_Listener listener)
g_return_val_if_fail (IS_CAL_BACKEND (backend), NULL);
cal = CAL (gtk_type_new (CAL_TYPE));
- corba_cal = cal_corba_object_create (GNOME_OBJECT (cal));
+ corba_cal = cal_corba_object_create (BONOBO_OBJECT (cal));
CORBA_exception_init (&ev);
ret = CORBA_Object_is_nil ((CORBA_Object) corba_cal, &ev);
@@ -230,13 +230,13 @@ cal_construct (Cal *cal,
/**
* cal_corba_object_create:
- * @object: #GnomeObject that will wrap the CORBA object.
+ * @object: #BonoboObject that will wrap the CORBA object.
*
* Creates and activates the CORBA object that is wrapped by the specified